@@ -13,7 +13,7 @@
 	
 
          Voicetronix Voice Processing Board (VPB) Software
-         Copyright (C) 1999-2007 Voicetronix www.voicetronix.com.au
+         Copyright (C) 1999-2008 Voicetronix www.voicetronix.com.au
 
          This library is free software; you can redistribute it and/or
          modify it under the terms of the GNU Lesser General Public
@@ -59,6 +59,7 @@
 
 #include <cassert>
 #include <cstdarg>
+#include <cstdio>
 #include <cstdlib>
 #include <cstring>
 #include <csetjmp>
@@ -709,7 +710,7 @@ static Country Countries[] =
 	  lv_offhook:    11,
 	  drop_time:     500,
 	  drop_min:      100,
-	  drop_max:      800,
+	  drop_max:      2500,
 	  fsk_mark:      0.942477769,
 	  fsk_space:     1.72787596,
 	  tone_gen:      us_tones
@@ -2829,6 +2830,8 @@ int WINAPI vpb_bridge( VPBPortHandle h1,  // handle of first channel
 				mprintf("Bridging PRI\n");
 				// cant bridge across boards 
 				if(b1 != b2){
+					if( vpb_soft_bridge(h1,h2,mode) == VPB_OK )
+						break;
 					throw Wobbly(VPBAPI_BRIDGE_DIFFERENT_BOARDS);
 				}
 
@@ -3059,7 +3062,6 @@ int WINAPI vpb_listen( VPBPortHandle h1, // handle of first channel
 { //{{{
 	unsigned short	b1,ch1,b2,ch2;
 	uint16_t	m[PC_LSPI_SBRIDGE];
-	int 	model;
 
 	try {
 		// can't bridge a port to itself  XXX
@@ -3067,11 +3069,12 @@ int WINAPI vpb_listen( VPBPortHandle h1, // handle of first channel
 		maphndletodev(h1, &b1, &ch1);
 		maphndletodev(h2, &b2, &ch2);
 
-		model = vpb_c->vpbreg(b1)->model;
-
-		switch(model) {
+		switch(vpb_c->vpbreg(b1)->model) {
 
 		    case VPB_PRI:
+			if(b1 != b2)
+				throw Wobbly(VPBAPI_BRIDGE_DIFFERENT_BOARDS);
+
 			if(mode == VPB_BRIDGE_ON) {
 				vpb_c->vpbreg(b1)->listen_info[ch1].board=b2;
 				vpb_c->vpbreg(b1)->listen_info[ch1].chan=ch2;
@@ -3102,6 +3105,13 @@ int WINAPI vpb_listen( VPBPortHandle h1, // handle of first channel
 
 		    case VPB_OSW:
 		    case VPB_OPCI:
+			{
+				int model2 = vpb_c->vpbreg(b2)->model;
+
+				if (model2 != VPB_OPCI && model2 != VPB_OSW)
+					throw Wobbly(VPBAPI_BRIDGE_DIFFERENT_BOARDS);
+			}
+
 			if(mode == VPB_BRIDGE_ON) {
 				vpb_c->vpbreg(b1)->listen_info[ch1].board=b2;
 				vpb_c->vpbreg(b1)->listen_info[ch1].chan=ch2;
